==> nextcloud-25.0.12p1.tgz: nextcloud/apps/systemtags/l10n/eo.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Etikednomo malplenas",
    "Update" : "Ĝisdatigi",
    "Create" : "Krei",
    "Select tag …" : "Elekti etikedon…",
    "System tag %1$s added by the system" : "Sistema etikedo %1$s aldonita de la sistemo",
    "Added system tag {systemtag}" : "Sistema etikedo {systemtag} aldonita",
    "Added system tag %1$s" : "Sistema etikedo %1$s aldonita",
    "%1$s added system tag %2$s" : "%1$s aldonis sisteman etikedon %2$s",
    "{actor} added system tag {systemtag}" : "{actor} aldonis sisteman etikedon {systemtag}",
    "System tag %1$s removed by the system" : "Sistema etikedo %1$s forigita de la sistemo",
    "Removed system tag {systemtag}" : "Sistema etikedo {systemtag} forigita",
    "Removed system tag %1$s" : "Sistema etikedo %1$s forigita",
    "%1$s removed system tag %2$s" : "%1$s forigis sisteman etikedon %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} forigis sisteman etikedon {systemtag}",
    "You created system tag %1$s" : "Vi kreis sisteman etikedon %1$s",
    "You created system tag {systemtag}" : "Vi kreis sisteman etikedon {systemtag}",
    "%1$s created system tag %2$s" : "%1$s kreis sisteman etikedon %2$s",
    "{actor} created system tag {systemtag}" : "{actor} kreis sisteman etikedon {systemtag}",
    "You deleted system tag %1$s" : "Vi forigis sisteman etikedon %1$s",
    "You deleted system tag {systemtag}" : "Vi forigis sisteman etikedon {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s forigis sisteman etikedon %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} forigis sisteman etikedon {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vi ĝisdatigis sisteman etikedon %2$s al %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vi ĝisdatigis sisteman etikedon {oldsystemtag} al {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ĝisdatigis sisteman etikedon %3$s al %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ĝisdatigis sisteman etikedon {oldsystemtag} al {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Sisteman etikedon %2$s aldonis al %1$s la sistemo",
    "System tag {systemtag} was added to {file} by the system" : "Sisteman etikedon {systemtag} aldonis al {file} la sistemo",
    "You added system tag %2$s to %1$s" : "Vi aldonis sisteman etikedon %2$s al %1$s",
    "You added system tag {systemtag} to {file}" : "Vi aldonis sisteman etikedon {systemtag} al {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s aldonis sisteman etikedon %3$s al %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} aldonis sisteman etikedon {systemtag} al {file}",
    "System tag %2$s was removed from %1$s by the system" : "Sisteman etikedon %2$s forigis el %1$s la sistemo",
    "System tag {systemtag} was removed from {file} by the system" : "Sisteman etikedon {systemtag} forigis el {file} la sistemo",
    "You removed system tag %2$s from %1$s" : "Vi forigis sisteman etikedon %2$s el %1$s",
    "You removed system tag {systemtag} from {file}" : "Vi forigis sisteman etikedon {systemtag} el {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s forigis sisteman etikedon %3$s el %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} forigis sisteman etikedon {systemtag} el {file}",
    "%s (restricted)" : "%s (limigita)",
    "%s (invisible)" : "%s (nevidebla)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistemaj etikedoj</strong> por dosiero modifiĝis",
    "Tags" : "Etikedoj",
    "Collaborative tags" : "Kunlaboraj etikedoj",
    "Collaborative tagging functionality which shares tags among users." : "Kunlabora etikedado por kunhavigi etikedojn inter uzantoj.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Kunlabora etikedado por kunhavigi etikedojn inter uzantoj. Taŭga por teamoj.\n\n(Se vi estas provizanto kun plurklienta instalado, oni konsilas malŝalti tiun aplikaĵon, alimaniere etikedoj estus kunhavigitaj inter ĉiuj klientoj.)",
    "Failed to load tags" : "Ŝargo de la etikedoj malsukcesis",
    "No tags found" : "Neniu etikedo troviĝis ",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Kunlaboraj etikedoj disponeblas al ĉiuj uzantoj. Limigitaj etikedoj videblas de uzantoj, kiuj tamen ne povas atribui ilin. Nevideblaj etikedoj servas por interna uzo, ĉar uzantoj nek vidas nek povas atribui ilin.",
    "Create a new tag" : "Krei novan etikedon",
    "Name" : "Nomo",
    "Public" : "Publika",
    "Restricted" : "Limigita",
    "Invisible" : "Nevidebla",
    "Delete" : "Forigi",
    "Reset" : "Restarigi",
    "No files in here" : "Neniu dosiero estas ĉi tie",
    "No entries found in this folder" : "Neniu elemento troviĝas en ĉi tiu dosierujo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "Tagged files" : "Etikeditaj dosieroj",
    "Select tags to filter by" : "Elekti etikedojn, per kiuj filtri",
    "Please select tags to filter by" : "Bonvolu elekti etikedojn, per kiuj filtri",
    "No files found for the selected tags" : "Neniu dosiero troviĝis por la elektitaj etikedoj"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.4.tgz: nextcloud/apps/systemtags/l10n/eo.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Sistema etikedo %1$s aldonita de la sistemo",
    "Added system tag {systemtag}" : "Sistema etikedo {systemtag} aldonita",
    "Added system tag %1$s" : "Sistema etikedo %1$s aldonita",
    "%1$s added system tag %2$s" : "%1$s aldonis sisteman etikedon %2$s",
    "{actor} added system tag {systemtag}" : "{actor} aldonis sisteman etikedon {systemtag}",
    "System tag %1$s removed by the system" : "Sistema etikedo %1$s forigita de la sistemo",
    "Removed system tag {systemtag}" : "Sistema etikedo {systemtag} forigita",
    "Removed system tag %1$s" : "Sistema etikedo %1$s forigita",
    "%1$s removed system tag %2$s" : "%1$s forigis sisteman etikedon %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} forigis sisteman etikedon {systemtag}",
    "You created system tag %1$s" : "Vi kreis sisteman etikedon %1$s",
    "You created system tag {systemtag}" : "Vi kreis sisteman etikedon {systemtag}",
    "%1$s created system tag %2$s" : "%1$s kreis sisteman etikedon %2$s",
    "{actor} created system tag {systemtag}" : "{actor} kreis sisteman etikedon {systemtag}",
    "You deleted system tag %1$s" : "Vi forigis sisteman etikedon %1$s",
    "You deleted system tag {systemtag}" : "Vi forigis sisteman etikedon {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s forigis sisteman etikedon %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} forigis sisteman etikedon {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vi ĝisdatigis sisteman etikedon %2$s al %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vi ĝisdatigis sisteman etikedon {oldsystemtag} al {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ĝisdatigis sisteman etikedon %3$s al %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ĝisdatigis sisteman etikedon {oldsystemtag} al {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Sisteman etikedon %2$s aldonis al %1$s la sistemo",
    "System tag {systemtag} was added to {file} by the system" : "Sisteman etikedon {systemtag} aldonis al {file} la sistemo",
    "You added system tag %2$s to %1$s" : "Vi aldonis sisteman etikedon %2$s al %1$s",
    "You added system tag {systemtag} to {file}" : "Vi aldonis sisteman etikedon {systemtag} al {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s aldonis sisteman etikedon %3$s al %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} aldonis sisteman etikedon {systemtag} al {file}",
    "System tag %2$s was removed from %1$s by the system" : "Sisteman etikedon %2$s forigis el %1$s la sistemo",
    "System tag {systemtag} was removed from {file} by the system" : "Sisteman etikedon {systemtag} forigis el {file} la sistemo",
    "You removed system tag %2$s from %1$s" : "Vi forigis sisteman etikedon %2$s el %1$s",
    "You removed system tag {systemtag} from {file}" : "Vi forigis sisteman etikedon {systemtag} el {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s forigis sisteman etikedon %3$s el %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} forigis sisteman etikedon {systemtag} el {file}",
    "%s (restricted)" : "%s (limigita)",
    "%s (invisible)" : "%s (nevidebla)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistemaj etikedoj</strong> por dosiero modifiĝis",
    "Tags" : "Etikedoj",
    "Collaborative tags" : "Kunlaboraj etikedoj",
    "Collaborative tagging functionality which shares tags among users." : "Kunlabora etikedado por kunhavigi etikedojn inter uzantoj.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Kunlabora etikedado por kunhavigi etikedojn inter uzantoj. Taŭga por teamoj.\n\n(Se vi estas provizanto kun plurklienta instalado, oni konsilas malŝalti tiun aplikaĵon, alimaniere etikedoj estus kunhavigitaj inter ĉiuj klientoj.)",
    "Create" : "Krei",
    "Update" : "Ĝisdatigi",
    "Delete" : "Forigi",
    "Reset" : "Restarigi",
    "Loading …" : "Ŝargado...",
    "Public" : "Publika",
    "Restricted" : "Limigita",
    "Invisible" : "Nevidebla",
    "Failed to load tags" : "Ŝargo de la etikedoj malsukcesis",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Kunlaboraj etikedoj disponeblas al ĉiuj uzantoj. Limigitaj etikedoj videblas de uzantoj, kiuj tamen ne povas atribui ilin. Nevideblaj etikedoj servas por interna uzo, ĉar uzantoj nek vidas nek povas atribui ilin.",
    "No tags found" : "Neniu etikedo troviĝis ",
    "No files in here" : "Neniu dosiero estas ĉi tie",
    "No entries found in this folder" : "Neniu elemento troviĝas en ĉi tiu dosierujo",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "Tag name is empty" : "Etikednomo malplenas",
    "Select tag …" : "Elekti etikedon…",
    "Tagged files" : "Etikeditaj dosieroj",
    "Select tags to filter by" : "Elekti etikedojn, per kiuj filtri",
    "Please select tags to filter by" : "Bonvolu elekti etikedojn, per kiuj filtri",
    "No files found for the selected tags" : "Neniu dosiero troviĝis por la elektitaj etikedoj",
    "Create a new tag" : "Krei novan etikedon"
},
"nplurals=2; plural=(n != 1);");
